# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), 
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.10.0] - 2025-06-25 14:31:58

### Added

- Estimate function, over loss matrix.

## [0.9.0] - 2025-06-24 16:38:27

### Added

- Small performance dashboard fix.

## [0.8.0] - 2025-06-24 13:08:56

### Added

- Creating github artifact to save calibration log for test.
- Interface to load CSVs from GitHub.

## [0.7.0] - 2025-06-24 10:25:50

### Added

- Adding the calibration performance dashboard link to documentation.

## [0.6.0] - 2025-06-24 09:23:16

### Added

- Calibration performance dashboard.

## [0.5.0] - 2025-06-23 10:15:54

### Added

- Test for warning logic in Calibration() input checks.

## [0.4.0] - 2025-06-20 12:55:18

### Added

- Summary of calibration results.

## [0.3.0] - 2025-06-20 11:03:38

### Added

- Logging performance across epochs when calibrating.

## [0.2.0] - 2025-06-19 16:34:04

### Added

- Basic Calibration input checks.

## [0.1.0] - 2025-06-18 13:44:19

### Added

- Initialized project.

## [0.1.0] - 2025-06-18 13:19:30

### Changed

- Initialized changelogging.



[0.10.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.9.0...0.10.0
[0.9.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.8.0...0.9.0
[0.8.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.7.0...0.8.0
[0.7.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.6.0...0.7.0
[0.6.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.5.0...0.6.0
[0.5.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.4.0...0.5.0
[0.4.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.3.0...0.4.0
[0.3.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.2.0...0.3.0
[0.2.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.1.0...0.2.0
[0.1.0]: https://github.com/PolicyEngine/microcalibrate/compare/0.1.0...0.1.0
